# undidPyjl
Difference-in-differences for unpoolable data. Python wrapper for Undid.jl.

![Multiple silos plotted](images/undid_plot_multiple_silos.png)

![Simple undid plot](images/undid_plot_simple.png)
